|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r78117 - trunk/libs/context/src/asm
From: oliver.kowalke_at_[hidden]
Date: 2012-04-21 17:06:12
Author: olli
Date: 2012-04-21 17:06:11 EDT (Sat, 21 Apr 2012)
New Revision: 78117
URL: http://svn.boost.org/trac/boost/changeset/78117
Log:
context: corected label for ppc in make_context
Text files modified:
trunk/libs/context/src/asm/fcontext_ppc32_sysv_elf_gas.S | 17 +++++------------
trunk/libs/context/src/asm/fcontext_ppc64_sysv_elf_gas.S | 15 ++++-----------
2 files changed, 9 insertions(+), 23 deletions(-)
Modified: trunk/libs/context/src/asm/fcontext_ppc32_sysv_elf_gas.S
==============================================================================
--- trunk/libs/context/src/asm/fcontext_ppc32_sysv_elf_gas.S (original)
+++ trunk/libs/context/src/asm/fcontext_ppc32_sysv_elf_gas.S 2012-04-21 17:06:11 EDT (Sat, 21 Apr 2012)
@@ -214,22 +214,15 @@
mflr %r0 # load LR
bl 1f # jump to label 1
1:
- mflr %r4 # load LR
- addi %r4, %r4, link_fcontext - 1b # calulate absolute address of link_fcontext
- mtlr %r0 # restore LR
- stw %r4, 84(%r3) # save address of link_fcontext
+ mflr %r4 # load LR
+ addi %r4, %r4, finish - 1b # calulate absolute address of finish
+ mtlr %r0 # restore LR
+ stw %r4, 84(%r3) # save address of finish
li %r3, 0 # set return value to zero
blr
-link_fcontext:
- mr. %r3, %r13
- mr. %r4, %r14
- beq 2f # test if a next context was given
-
- bl start_fcontext_at_plt # install next context
-
-2:
+finish:
li %r3, 0 # set return value to zero
bl _exit_at_plt # exit application
.size make_fcontext, .-make_fcontext
Modified: trunk/libs/context/src/asm/fcontext_ppc64_sysv_elf_gas.S
==============================================================================
--- trunk/libs/context/src/asm/fcontext_ppc64_sysv_elf_gas.S (original)
+++ trunk/libs/context/src/asm/fcontext_ppc64_sysv_elf_gas.S 2012-04-21 17:06:11 EDT (Sat, 21 Apr 2012)
@@ -242,22 +242,15 @@
mflr %r0 # load LR
bl 1f # jump to label 1
1:
- mflr %r4 # load LR
- addi %r4, %r4, link_fcontext - 1b # calulate absolute address of link_fcontext
+ mflr %r4 # load LR
+ addi %r4, %r4, finish - 1b # calulate absolute address of finish
mtlr %r0 # restore LR
- std %r4, 168(%r3) # save address of link_fcontext
+ std %r4, 168(%r3) # save address of finish
li %r3, 0 # set return value to zero
blr
-link_fcontext:
- mr. %r3, %r13
- mr. %r4, %r14
- beq 2f # test if a next context was given
-
- bl start_fcontext_at_plt # install next context
-
-2:
+finish:
li %r3, 0 # set return value to zero
bl _exit_at_plt # exit application
.size .make_fcontext, .-.make_fcontext
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk